import QtQuick 2.12
import QtQuick.Window 2.12
import QtQuick.Controls 2.5
import QtQuick.Layouts 1.15
import QtQuick.Controls.Material 2.3
import org.ukui.shortcut.bluetooth 1.0

import org.ukui.quick.items 1.0 as UkuiItems
import org.ukui.quick.platform 1.0 as Platform


UkuiItems.DtThemeBackground {
    id: root
    backgroundColor: Platform.GlobalTheme.kContainSecondaryAlphaNormal
    radius: Platform.GlobalTheme.kRadiusWindow

    ColumnLayout {
        anchors.fill: parent
        spacing: 0

        RowLayout {
            id: bttop
            width: parent.width
            Layout.alignment: Qt.AlignTop

            Item { Layout.fillWidth: true }

            SwitchDelegate {
                id: btpower
                checked: BtInterface.btPower
                onClicked: {
                    BtInterface.btPower = !BtInterface.btPower
                }
                Layout.alignment: Qt.AlignRight
                Layout.rightMargin: 10
            }
        }

        
        Rectangle {
            Layout.alignment: Qt.AlignTop
            Layout.fillWidth: true
            height: 1
        }

        Item {
            visible: !BtInterface.btPower
            Layout.fillHeight: true
        }

        Rectangle {
            visible: BtInterface.btPower
            Layout.alignment: Qt.AlignTop
            height: 40
            Label {
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.verticalCenter: parent.verticalCenter
                text: qsTr("My Devices")
            }
        }
        
        ScrollView {
            visible: BtInterface.btPower
            Layout.alignment: Qt.AlignVCenter
            Layout.fillWidth: true
            Layout.fillHeight: true
            ScrollBar.vertical.policy: {
                listView.contentHeight > listView.height ?
                        ScrollBar.AlwaysOn : ScrollBar.AlwaysOff
            }
            ListView {
                id: listView
                anchors.fill: parent
                model: BtInterface.deviceList
                clip: true
                spacing: 1

                // 定义每个项的显示方式
                delegate: ItemDelegate {
                    highlighted: enteritem && listView.currentIndex == index
                    width: parent.width
                    height: 45
                    Layout.leftMargin: 8
                    property bool enteritem : false

                    RowLayout {
                        anchors.fill: parent 
                         
                        Rectangle {
                            Layout.alignment: Qt.AlignLeft
                            Layout.leftMargin: 16
                            width: parent.height - 10
                            height: parent.height - 10
                            radius: width / 2
                            
                            UkuiItems.IconButton {
                                visible: !modelData.Connecting
                                iconSource: BtInterface.getBluetoothIcon(modelData.Type)
                                anchors.fill: parent
                                id: typeicon
                                radius: parent.radius
                                anchors.centerIn: parent
                                isHighLight: modelData.Connected
                            }

                            Image{
                                visible: modelData.Connecting
                                anchors.centerIn: parent
                                id: loadingicon
                                source: BtInterface.getBluetoothIcon(modelData.LoadingIcon);
                                RotationAnimation on rotation {
                                    from: 0
                                    to: 360
                                    duration: 2000 // 旋转一圈需要的时间，单位为毫秒
                                    loops: Animation.Infinite // 无限循环
                               }
                            }
                        }

                        Text {
                            id: label1
                            Layout.alignment: Qt.AlignLeft
                            Layout.leftMargin: 8
                            Layout.preferredWidth: 150
                            text: modelData.Name
                        }

                        Item { Layout.fillWidth: true }

                        Rectangle {
                            visible: (modelData.Battery >= 0 && modelData.Connected)  ? true : false
                            width: 80
                            Layout.alignment: Qt.AlignRight | Qt.AlignVCenter
                            Layout.rightMargin:24


                            Text {
                                anchors.right: batteryicon.left
                                anchors.rightMargin: 4
                                anchors.verticalCenter: parent.verticalCenter
                                id: batterytext
                                text: modelData.Battery + "%"
                            }

                            Image {
                                id: batteryicon
                                anchors.right: parent.right
                                anchors.rightMargin: 24
                                anchors.verticalCenter: parent.verticalCenter
                                source: BtInterface.getBluetoothBatteryIcon(modelData.Battery);
                            }
                        }
                    }

                    MouseArea {
                        anchors.fill: parent
                        hoverEnabled: true
                        onClicked: {
                            // // 设置当前选中项
                            var key1 = modelData.Connected ? "devDisconnect" : "devConnect";
                            console.log(key1)
                            var mapData = {};
                            mapData[key1] = modelData.Addr;
                            BtInterface.setBluetoothConfig(mapData);
                            if(modelData.Connected) {
                                typeicon.visible = false;
                                loadingicon.visible = true;
                                loadingicon.parent.color = typeicon.color;
                            } else {
                                loadingicon.parent.color = typeicon.color;
                            }
                        }
                        onEntered: {
                            enteritem = true
                            listView.currentIndex = index;
                        }
                        onExited: {
                            listView.currentIndex = -1
                            enteritem = false
                        }
                    }

                    Connections {
                        target: BtInterface
                        onUpdatePairedDevice : {
                            if(device === modelData.Addr) {
                                if(attrs.hasOwnProperty("Connecting")) {
                                    typeicon.visible = !attrs.Connecting;
                                    loadingicon.visible = attrs.Connecting;
                                }
                                if(attrs.hasOwnProperty("Battery")) {
                                    batteryicon.source = BtInterface.getBluetoothBatteryIcon(attrs.Battery);
                                    batterytext.text = attrs.Battery + "%"
                                }
                            }
                        }
                    }
                }
            }
        }

        Rectangle {
            id: btx2
            Layout.alignment: Qt.AlignBottom
            Layout.fillWidth: true
            height: 1
        }

        Rectangle {
            id: btx3
            Layout.fillWidth: true
            height: 40
            Layout.alignment: Qt.AlignBottom
            Text {
                anchors.left: parent.left
                anchors.leftMargin: 20
                anchors.verticalCenter: parent.verticalCenter
                text: qsTr("More Bluetooth Settings")
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    console.log(bttop.height)
                    console.log(btx3.height)
                }
            }
        }
    }
}
